<template>
  <div class="info-dispatch">
    <div class="content" v-if="employeeList.length > 0">
      <div class="employee-box" v-for="(item, index) in employeeList" :key="index" @click="select(item)">
        <van-checkbox class="checkbox" v-model="item.checked" :disabled="item.dutyStatus !== 'SignIn'"></van-checkbox>
        <avatar :size="40">
          <div class="per-name">
            {{ item.nameSlice }}
          </div>
        </avatar>
        <div class="info">
          <div class="title">{{ item.name }}（{{ item.dutyStatusText }}）</div>
          <div class="detail">
            <span class="label">所属公司：</span>
            <span class="value">{{ item.companyName }}</span>
          </div>
          <div class="detail">
            <span class="label">所属驻勤点：</span>
            <span class="value">{{ item.securityStationName }}</span>
          </div>
          <div class="detail">
            <span class="label">联系方式：</span>
            <span v-if="!item.concatVisible" class="value">{{ item.contactHide }}</span>
            <span v-if="item.concatVisible" class="value">{{ item.contact }}</span>
            <span class="visible" @click.stop="item.concatVisible = !item.concatVisible">{{
              item.concatVisible ? "隐藏" : "显示"
            }}</span>
          </div>
          <div class="detail">
            <span class="label">证件号码：</span>
            <span v-if="!item.idVisible" class="value">{{ item.idCardNoHide }}</span>
            <span v-if="item.idVisible" class="value">{{ item.idCardNo }}</span>
            <span class="visible" @click.stop="item.idVisible = !item.idVisible">{{ item.idVisible ? "隐藏" : "显示" }}</span>
          </div>
        </div>
      </div>
    </div>
    <div class="dispatch" v-if="employeeList.length > 0">
      <div class="title">当前共选择{{ selectedCount }}人</div>
      <div class="btn-list">
        <van-button class="btn" plain hairline size="mini" type="info" @click="openGroupFormDialog">文字调度</van-button>
        <van-button class="btn" plain hairline size="mini" type="info" @click="dispatch('audio')">语音调度</van-button>
        <van-button class="btn" plain hairline size="mini" type="info" @click="dispatch('video')">视频调度</van-button>
        <van-button class="btn" plain hairline size="mini" type="info" @click="dispatch('videoLocalMute')">视频上拉</van-button>
      </div>
    </div>
    <van-empty v-else description="暂无数据" />
  </div>
</template>

<script>
import { Empty, Button, Checkbox, Toast } from "vant";
import Avatar from "@components/avatar.vue";

export default {
  name: "infoDispatch",
  components: {
    [Empty.name]: Empty,
    [Checkbox.name]: Checkbox,
    [Button.name]: Button,
    [Toast.name]: Toast,
    Avatar,
  },
  props: {
    data: Object,
  },
  data() {
    return {
      // employeeList: [],
    };
  },
  computed: {
    employeeList() {
      return this.data?.employeeList || [];
    },
    selectedCount() {
      return this.data.employeeList.filter((x) => x.checked).length;
    },
  },
  methods: {
    select(item) {
      const { dutyStatus, checked } = item;
      if (dutyStatus === "SignIn") {
        item.checked = !checked;
      }
    },
    dispatch(type) {
      this.$emit("dispatch", {
        type,
        memberList: this.data.employeeList.filter((x) => x.checked),
      });
    },
    openGroupFormDialog() {
      console.log(this.data.employeeList);
      const members = this.data.employeeList.filter((x) => x.checked);
      if (members.length > 0) {
        this.$emit("conversation", members);
      } else {
        Toast.fail("至少选择一名被调度人");
      }
    },
  },
};
</script>

<style scoped lang="less">
.info-dispatch {
  .content {
    padding: 24px 20px;
    overflow-y: auto;
    overflow-x: hidden;
    max-height: calc(3 * 137.5px);
    .employee-box {
      width: 100%;
      height: 137.5px;
      border-bottom: 1px solid #d8d8d8;
      display: flex;
      flex-direction: row;
      padding-top: 12px;
      justify-content: space-between;
      position: relative;
      .checkbox {
        position: absolute;
        right: 0;
        top: 50%;
        transform: translate(-50%, 0);
      }
      .per-name {
        height: 40px;
        width: 40px;
        background: #0e71ff;
        color: #fff;
        font-size: 12px;
        display: flex;
        align-items: center;
        justify-content: center;
      }
      .info {
        width: 287px;
        //padding: 12px 20px;
        .title {
          font-size: 14px;
          font-family: PingFang SC-Medium, PingFang SC;
          font-weight: 500;
          color: #303133;
          line-height: 22px;
          margin-bottom: 2px;
        }
        .detail {
          width: 100%;
          display: flex;
          align-items: center;
          margin-bottom: 10px;
          &:last-child {
            margin-bottom: 0;
          }
          .label {
            font-size: 12px;
            font-family: PingFang SC-Regular, PingFang SC, serif;
            font-weight: 400;
            color: #909399;
          }
          .value {
            font-size: 12px;
            font-family: PingFang SC-Regular, PingFang SC;
            font-weight: 400;
            color: #303133;
            &-link {
              font-size: 12px;
              font-family: PingFang SC-Regular, PingFang SC;
              font-weight: 400;
              color: #0f71ff;
              text-decoration: underline;
            }
          }
          .visible {
            font-size: 12px;
            font-family: PingFang SC-Regular, PingFang SC;
            font-weight: 400;
            color: #0f71ff;
            margin-left: 2px;
          }
        }
      }
    }
  }
  .dispatch {
    width: 100%;
    padding: 8px 20px;
    .title {
      font-size: 12px;
      line-height: 22px;
      font-family: PingFang SC-Medium, PingFang SC, serif;
      font-weight: 500;
      color: #3d3d3d;
      margin-bottom: 10px;
    }
    .btn-list {
      display: flex;
      flex-direction: row;
      flex-wrap: wrap;
      .btn {
        margin-bottom: 14px;
        margin-right: 10px;
        margin-left: 0;
        width: 78px;
        //border-radius: 6px 6px 6px 6px;
      }
    }
  }
}
</style>
